#!/bin/bash

set -e

# Load config from ../.env
env_file="$(dirname "$0")/../.env"
if [[ -f "$env_file" ]]; then
    set -a
    source "$env_file"
    set +a
else
    echo "Error: config file '../.env' not found."
    exit 1
fi

# Required variables from .env
required_vars=(file1 file2 user1 user2 machine1 machine2 logdir)

for var in "${required_vars[@]}"; do
    if [[ -z "${!var}" ]]; then
        echo "Error: Required variable '$var' is not set in $env_file"
        exit 1
    fi
done

# Parse arguments
while [[ "$#" -gt 0 ]]; do
    case $1 in
        -o|--output)
            output="$2"
            shift 2
            ;;
        -*)
            echo "Unknown option: $1"
            exit 1
            ;;
        *)
            if [[ -z "$expid" ]]; then
                expid="$1"
                shift
            else
                echo "Unexpected argument: $1"
                exit 1
            fi
            ;;
    esac
done

# Check if expid was provided
if [[ -z "$expid" ]]; then
    echo "Usage: $0 <expid> [--output <output_dir>]"
    exit 1
fi

# Set default output if not provided
if [[ -z "$output" ]]; then
    output="$logdir/$expid"
fi

# Expand ~ and variables
eval file1="$file1"
eval file2="$file2"
eval output="$output"

root="/appl/AS/AUTOSUBMIT_DATA/$expid/tmp/"
ssh_cmd="ssh -i $file2 -J $user1@$machine1 -i $file1"

# Create output subdirectories
mkdir -p "$output/ASFILES" "$output/LOGS" "$output/ASLOGS"

# Rsync commands
rsync -avPz -e "$ssh_cmd" --exclude '*/' $user2@$machine2:"$root" "$output/ASFILES"
rsync -avPz -e "$ssh_cmd" --exclude '*/' $user2@$machine2:"$root/LOG_$expid/" "$output/LOGS"
rsync -avPz -e "$ssh_cmd" --exclude '*/' $user2@$machine2:"$root/ASLOGS/" "$output/ASLOGS"
